import type { RepairResVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  repairResExport = '/eims/repairRes/export',
  repairResList = '/eims/repairRes/list',
  root = '/eims/repairRes'
}

/**
 * 查询维修工单列表
 * @param query
 * @returns {*}
 */

export function listRepairRes(params?: any) {
  return requestClient.get<RepairResVO[]>(Api.repairResList, { params });
}

/**
 * 查询维修工单详细
 * @param repairResId
 */
export function getRepairRes(repairResId: ID) {
  return requestClient.get<RepairResVO>(`${Api.root}/${repairResId}`);
}

/**
 * 新增维修工单
 * @param data
 */
export function addRepairRes(data: any) {
  return requestClient.postWithMsg<void>(`${Api.root}/add`, data);
}

/**
 * 新增维修工单-批量
 * @param data
 */
export function addBatchRepairRes(data: any) {
  return requestClient.postWithMsg<void>(`${Api.root}/addBatch`, data);
}

/**
 * 修改维修工单
 * @param data
 */
export function updateRepairRes(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除维修工单
 * @param repairResId
 */
export function delRepairRes(repairResId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${repairResId}`);
}
/**
 * 导出
 * @param
 */
export function repairResExport(data: any) {
  return commonExport(Api.repairResExport, data);
}
